@@ -9,8 +9,6 @@ from fastapi.testclient import TestClient
 from inline_snapshot import snapshot
 from pydantic import BaseModel, Field
 
-from tests.utils import pydantic_snapshot
-
 
 class MessageEventType(str, Enum):
     alpha = "alpha"
@@ -126,47 +124,21 @@ def test_openapi_schema():
                     },
                     "MessageEvent": {
                         "properties": {
-                            "event_type": pydantic_snapshot(
-                                v2=snapshot(
-                                    {
-                                        "$ref": "#/components/schemas/MessageEventType",
-                                        "default": "alpha",
-                                    }
-                                ),
-                                v1=snapshot(
-                                    {
-                                        "allOf": [
-                                            {
-                                                "$ref": "#/components/schemas/MessageEventType"
-                                            }
-                                        ],
-                                        "default": "alpha",
-                                    }
-                                ),
-                            ),
+                            "event_type": {
+                                "$ref": "#/components/schemas/MessageEventType",
+                                "default": "alpha",
+                            },
                             "output": {"type": "string", "title": "Output"},
                         },
                         "type": "object",
                         "required": ["output"],
                         "title": "MessageEvent",
                     },
-                    "MessageEventType": pydantic_snapshot(
-                        v2=snapshot(
-                            {
-                                "type": "string",
-                                "enum": ["alpha", "beta"],
-                                "title": "MessageEventType",
-                            }
-                        ),
-                        v1=snapshot(
-                            {
-                                "type": "string",
-                                "enum": ["alpha", "beta"],
-                                "title": "MessageEventType",
-                                "description": "An enumeration.",
-                            }
-                        ),
-                    ),
+                    "MessageEventType": {
+                        "type": "string",
+                        "enum": ["alpha", "beta"],
+                        "title": "MessageEventType",
+                    },
                     "MessageOutput": {
                         "properties": {
                             "body": {"type": "string", "title": "Body", "default": ""},
